@@ -18,7 +18,9 @@
  *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.             *
  ***************************************************************************/
 
-#include "kgpgme.h"
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
 
 #ifdef HAVE_LIBGPGME
 
@@ -37,6 +39,8 @@
 #include <stdlib.h>
 #include <unistd.h>
 
+#include "kgpgme.h"
+
 // KGpgSelKey class based on class in KGpg with the same name
 
 class KGpgSelKey : public KDialogBase
@@ -378,12 +382,12 @@ void KGpgMe::setPassphraseCb()
 		if (agent_info.find(':'))
 			agent = true;
 		if(agent_info.startsWith("disable:"))
-			setenv("GPG_AGENT_INFO", agent_info.mid(8), 1);
+			setenv("GPG_AGENT_INFO", agent_info.mid(8).local8Bit(), 1);
 	}
 	else
 	{
 		if(!agent_info.startsWith("disable:"))
-			setenv("GPG_AGENT_INFO", "disable:" + agent_info, 1);
+			setenv("GPG_AGENT_INFO", "disable:" + agent_info.local8Bit(), 1);
 	}
 	if (agent)
 		gpgme_set_passphrase_cb(m_ctx, 0, 0);
